"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-process-exit */
const userConfig_1 = __importDefault(require("./userConfig"));
const cliConfig_1 = __importDefault(require("./cliConfig"));
const utils_1 = require("./utils");
const userPackageScripts_1 = __importDefault(require("./userPackageScripts"));
const loadRules_1 = require("./loadRules");
const execute_1 = __importDefault(require("./execute"));
const consoleReporter_1 = require("./consoleReporter");
const constants_1 = require("./constants");
/* istanbul ignore next */
const processExit = (code) => {
    if (typeof process.env.JEST_WORKER_ID === "undefined") {
        // eslint-disable-next-line node/no-process-exit
        process.exit(code);
    }
};
exports.default = (argv) => {
    var _a;
    try {
        /**
         * config assembly
         */
        const userConfig = (0, userConfig_1.default)();
        const cliConfig = (0, cliConfig_1.default)(argv);
        const config = Object.assign(Object.assign(Object.assign(Object.assign({}, constants_1.DEFAULT_CONFIG), { json: false }), userConfig), cliConfig);
        // output the config (--config) but only if we don't want JSON output on the CLI
        if (!config.json && config.config) {
            const json = JSON.stringify(config, null, 2);
            // eslint-disable-next-line no-console
            console.log(`\n\n${json}\n\n`);
        }
        /**
         * package.json
         */
        const { writePackageScripts, readPackageScripts } = (0, userPackageScripts_1.default)((0, utils_1.makePackageFilePath)((_a = config.packageFile) !== null && _a !== void 0 ? _a : process.cwd()));
        const scripts = readPackageScripts(config.ignoreScripts);
        /**
         * rule loading
         */
        const rules = (0, loadRules_1.loadRulesFromRuleConfig)(config.strict, config.rules, config.customRules);
        /**
         * and go!
         */
        const [issues, fixedScripts, issuesFixed] = (0, execute_1.default)(rules, scripts, consoleReporter_1.warning, config.fix);
        if (config.fix && issuesFixed > 0) {
            writePackageScripts(fixedScripts);
            (0, consoleReporter_1.success)(`Fixed ${issuesFixed} issue${issuesFixed > 1 ? "s" : ""}!`);
        }
        if (issues.length - issuesFixed === 0) {
            (0, consoleReporter_1.success)("✨  All good");
            (0, consoleReporter_1.dump)(config.json);
            processExit(constants_1.PROCESS_EXIT_OK);
        }
        (0, consoleReporter_1.dump)(config.json);
        processExit(constants_1.PROCESS_EXIT_ERROR);
    }
    catch (err) {
        (0, consoleReporter_1.error)(err.message);
    }
};
