"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.error = exports.dump = exports.success = exports.warning = void 0;
const chalk_1 = __importDefault(require("chalk"));
const utils_1 = require("./utils");
const PREFIX = "⧙։⧘";
let stashed = [];
const stash = (message, type) => {
    stashed.push({
        message,
        type,
    });
};
const warning = (template, values) => {
    const message = (0, utils_1.makeMessage)(template, values);
    stash(message, "warning");
};
exports.warning = warning;
const success = (template, values) => {
    const message = (0, utils_1.makeMessage)(template, values);
    stash(message, "success");
};
exports.success = success;
const dump = (jsonOutput) => {
    const problemCount = stashed.length;
    if (jsonOutput) {
        // eslint-disable-next-line no-console
        console.log(JSON.stringify(stashed, null, "\t"));
    }
    else {
        stashed.forEach(({ message, type }) => {
            print(type, message);
        });
    }
    stashed = [];
    return problemCount;
};
exports.dump = dump;
const error = (message) => {
    print("error", message);
};
exports.error = error;
const print = (type, message) => {
    switch (type) {
        case "error": {
            // eslint-disable-next-line no-console
            console.log(chalk_1.default.bold.red(`${PREFIX} [error] ${message}`));
            break;
        }
        case "warning": {
            const notUnderlined = chalk_1.default.yellow.bold(`${PREFIX} [${type}]`);
            const underlined = chalk_1.default.yellow.underline(message);
            // eslint-disable-next-line no-console
            console.log(`${notUnderlined} ${underlined}`);
            break;
        }
        case "success": {
            // eslint-disable-next-line no-console
            console.log(chalk_1.default.bold.gray(`${PREFIX} [✔️] ${message}`));
            break;
        }
    }
};
