"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadRulesFromRuleConfig = exports.getRuleByName = void 0;
const defaultRuleSets_1 = __importDefault(require("./defaultRuleSets"));
const rules_1 = __importDefault(require("./rules"));
const getRuleByName = (rules, name) => {
    const filtered = rules.filter((r) => r.name === name);
    if (filtered.length < 1) {
        return null;
    }
    return filtered[0];
};
exports.getRuleByName = getRuleByName;
const loadDefaultRulesFromSet = (strict) => {
    if (strict) {
        return defaultRuleSets_1.default.strict
            .map((name) => (0, exports.getRuleByName)(rules_1.default, name))
            .filter((r) => r !== null);
    }
    return defaultRuleSets_1.default.default
        .map((name) => (0, exports.getRuleByName)(rules_1.default, name))
        .filter((r) => r !== null);
};
const loadRulesFromRuleConfig = (strict, rulesConfig, customRules) => {
    const rules = loadDefaultRulesFromSet(strict);
    const loadedCustomRules = rulesConfig && customRules
        ? customRules.filter((cr) => rulesConfig[cr.name])
        : [];
    const loadedRules = [...loadedCustomRules, ...rules];
    if (!rulesConfig) {
        return loadedRules;
    }
    return loadedRules
        .map((rule) => {
        if (rule.name in rulesConfig && rulesConfig[rule.name] === false) {
            return null;
        }
        return rule;
    })
        .filter((r) => r !== null);
};
exports.loadRulesFromRuleConfig = loadRulesFromRuleConfig;
