#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// eslint-disable-next-line node/shebang
const userPackageScripts_1 = __importDefault(require("./userPackageScripts"));
const loadRules_1 = require("./loadRules");
const errors_1 = require("./errors");
const execute_1 = __importDefault(require("./execute"));
const constants_1 = require("./constants");
const utils_1 = require("./utils");
exports.default = (moduleConfig) => {
    /**
     * validate config
     */
    var _a, _b;
    if (moduleConfig.packageFile && moduleConfig.packageScripts) {
        throw new errors_1.ConfigError("Either specify a package.json location or a scripts object but not both" +
            JSON.stringify(moduleConfig));
    }
    if (!moduleConfig.packageFile && !moduleConfig.packageScripts) {
        throw new errors_1.ConfigError("You have to specify a package.json location or a scripts object");
    }
    const config = Object.assign(Object.assign({}, constants_1.DEFAULT_CONFIG), moduleConfig);
    /**
     * find scripts
     */
    let scripts = (_a = moduleConfig.packageScripts) !== null && _a !== void 0 ? _a : {};
    if (!moduleConfig.packageScripts && moduleConfig.packageFile) {
        const { readPackageScripts } = (0, userPackageScripts_1.default)((0, utils_1.makePackageFilePath)((_b = config.packageFile) !== null && _b !== void 0 ? _b : ""));
        scripts = readPackageScripts(config.ignoreScripts);
    }
    /**
     * ok go!
     */
    const rules = (0, loadRules_1.loadRulesFromRuleConfig)(config.strict, config.rules, config.customRules);
    const [issues, fixedScripts] = (0, execute_1.default)(rules, scripts, () => { }, config.fix);
    return {
        issues,
        scripts: config.fix ? fixedScripts : scripts,
    };
};
