"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../constants");
const utils_1 = require("../utils");
const getMissingHooks = (prefix, scripts) => {
    const keys = Object.keys(scripts);
    const hooks = keys.filter((k) => k.startsWith(prefix));
    const hooksMissing = [];
    hooks.forEach((hookName) => {
        const triggerName = hookName.substr(prefix.length);
        if (!keys.includes(triggerName)) {
            hooksMissing.push(triggerName);
        }
    });
    return hooksMissing;
};
exports.default = {
    name: "prepost-trigger-defined",
    isObjectRule: true,
    message: "some custom hooks ({{names}}) are missing their trigger script(s)",
    validate: (scripts) => {
        scripts = (0, utils_1.filterPackageScriptsByKeys)(scripts, constants_1.DEFAULT_NPM_HOOKS);
        const preHooksMissing = getMissingHooks("pre", scripts);
        const postHooksMissing = getMissingHooks("post", scripts);
        const allMissing = [
            ...preHooksMissing.map((s) => `pre${s}`),
            ...postHooksMissing.map((s) => `post${s}`),
        ];
        return allMissing.length < 1 ? true : allMissing;
    },
};
