"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeConfig = void 0;
const cosmiconfig_1 = require("cosmiconfig");
const constants_1 = require("./constants");
const errors_1 = require("./errors");
const sanitizeConfig = (loadedConfig) => {
    const sanitized = Object.assign(Object.assign({}, constants_1.DEFAULT_CONFIG), loadedConfig);
    Object.keys(sanitized).forEach((key) => {
        const keyExists = Object.keys(constants_1.DEFAULT_CONFIG).includes(key);
        if (!keyExists) {
            // eslint-disable-next-line @typescript-eslint/no-dynamic-delete
            delete sanitized[key];
            throw new errors_1.ConfigError(`unknown config key "${key}"`);
        }
    });
    // eslint-disable-next-line @typescript-eslint/no-unsafe-return
    return sanitized;
};
exports.sanitizeConfig = sanitizeConfig;
const loadConfig = (name = constants_1.PROJECT_NAME) => {
    const explorerSync = (0, cosmiconfig_1.cosmiconfigSync)(name);
    const searchedFor = explorerSync.search();
    if (!searchedFor) {
        return constants_1.DEFAULT_CONFIG;
    }
    return (0, exports.sanitizeConfig)(searchedFor.config);
};
exports.default = loadConfig;
