"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchScriptObjectEntry = exports.makeMessage = exports.filterPackageScriptsByKeys = exports.slugify = exports.makePackageFilePath = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const errors_1 = require("./errors");
const makePackageFilePath = (packageFile) => {
    // resolve package.json path
    packageFile = packageFile.endsWith("/package.json")
        ? packageFile
        : packageFile + "/package.json";
    packageFile = path_1.default.resolve(packageFile);
    // does it exist?
    if (!fs_1.default.existsSync(packageFile)) {
        throw new errors_1.PackageFileNotFoundError(packageFile);
    }
    return packageFile;
};
exports.makePackageFilePath = makePackageFilePath;
const slugify = (str) => str
    .trim()
    .toLowerCase()
    .replace(/[^A-Za-z-]/g, "-")
    .replace(/^-/g, "")
    .replace(/-+/g, "-")
    .replace(/-$/g, "");
exports.slugify = slugify;
const filterPackageScriptsByKeys = (raw, removes) => {
    return Object.keys(raw)
        .filter((k) => !removes.includes(k))
        .reduce((obj, key) => {
        obj[key] = raw[key];
        return obj;
    }, {});
};
exports.filterPackageScriptsByKeys = filterPackageScriptsByKeys;
const makeMessage = (template, values) => {
    let message = template;
    if (values !== undefined) {
        const pairs = Object.entries(values);
        pairs.forEach(([key, value]) => {
            message = message.replace(`{{${key}}}`, value);
        });
    }
    return message;
};
exports.makeMessage = makeMessage;
const fromEntries = (iterable) => {
    return [...iterable].reduce((obj, [key, val]) => {
        obj[key] = val;
        return obj;
    }, {});
};
const patchScriptObjectEntry = (scripts, fromKey, toKey, value) => fromEntries(Object.entries(scripts).map(([k, v]) => {
    return k === fromKey ? [toKey, value] : [k, v];
}));
exports.patchScriptObjectEntry = patchScriptObjectEntry;
